@@ -1,4 +1,4 @@
-// $Id: Agent.h,v 1.18 1998/03/25 12:42:10 zeller Exp $
+// $Id: Agent.h,v 1.19 1998/08/21 10:21:48 zeller Exp $
 // Three-Channel Agent Interface 
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -281,7 +281,7 @@ public:
     static AgentManager runningAgents;
 
     // Constructor for Agent users
-    Agent(string pth, unsigned nTypes = Agent_NTypes):
+    Agent(const string& pth, unsigned nTypes = Agent_NTypes):
 	_pid(0), _inputfp(0), _outputfp(0), _errorfp(0),
 	_running(false), _beingTerminated(false), _lastStatus(-1),
 	_terminateTimeOut(10), _hangupTimeOut(5), _killTimeOut(15),
