@@ -1,4 +1,4 @@
-// $Id: AppData.h,v 1.125.4.1 1998/12/06 12:59:15 zeller Exp $ -*- C++ -*-
+// $Id: AppData.h,v 1.125.4.2 1999/05/08 15:23:34 zeller Exp $ -*- C++ -*-
 // DDD application data
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
@@ -251,8 +251,9 @@
 #define XtNcheckOptions          "checkOptions"
 #define XtCCheckOptions          "CheckOptions"
 #define XtNttyMode               "ttyMode"
-#define XtNfullNameMode          "fullNameMode"
 #define XtCTTYMode               "TTYMode"
+#define XtNannotate              "annotate"
+#define XtCAnnotate              "Annotate"
 #define XtNblockTTYInput         "blockTTYInput"
 #define XtCBlockTTYInput         "BlockTTYInput"
 #define XtNdisplayGlyphs         "displayGlyphs"
@@ -512,7 +513,7 @@ struct AppData {
     Cardinal  check_options;
     Boolean   tty_mode;
     OnOff     block_tty_input;
-    Boolean   full_name_mode;
+    Cardinal  annotate;
     Boolean   display_glyphs;
     Cardinal  max_glyphs;
     Boolean   cache_glyph_images;
