@@ -1,4 +1,4 @@
-// $Id: cmdtty.h,v 1.6 1998/03/25 12:45:23 zeller Exp $ -*- C++ -*-
+// $Id: cmdtty.h,v 1.6.6.1 1999/05/08 15:23:37 zeller Exp $ -*- C++ -*-
 // TTY command interface
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -42,6 +42,9 @@ extern void init_command_tty();
 // Check if command tty is still running
 extern bool tty_running();
 
+// Output annotation TEXT when in annotation mode
+extern void annotate(char * text);
+
 // Output TEXT on controlling TTY, unless we've just composed a command
 extern void tty_out(const string& text);
 
