@@ -1,4 +1,4 @@
-// $Id: ddd.h,v 1.35 1998/06/09 07:36:02 zeller Exp $
+// $Id: ddd.h,v 1.37 1998/11/27 13:21:47 zeller Exp $
 // DDD application resources
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -65,6 +65,9 @@ extern void update_arg_buttons();
 // Update user-defined buttons
 extern void update_user_buttons();
 
+// Update `Edit' menu (esp. Undo and Redo actions)
+extern void update_edit_menus();
+
 // Save current option state
 extern void save_option_state();
 
@@ -92,6 +95,7 @@ extern class ArgField   *source_arg;
 // Where to log DDD I/O
 extern ostream *_dddlog;
 #define dddlog (*_dddlog)
+extern void init_dddlog();
 
 // Text to ignore upon output
 extern string gdb_out_ignore;
